@@ -10,11 +10,8 @@ class WithConfigRegistry:
     _registry: dict[str, type]
 
     def __init__(self) -> None:
-        # Register supported item types here
         from wexample_pseudocode.config.class_config import ClassConfig
-        from wexample_pseudocode.config.constant_config import (
-            ConstantConfig,  # local import to avoid cycles
-        )
+        from wexample_pseudocode.config.constant_config import ConstantConfig
         from wexample_pseudocode.config.function_config import FunctionConfig
 
         self._registry = {
@@ -23,11 +20,11 @@ class WithConfigRegistry:
             "function": FunctionConfig,
         }
 
-    def get_config_registry(self) -> WithConfigRegistry:
-        return self
-
     def find_matching_config_loader(self, data: dict) -> type | None:
         item_type = data.get("type")
         if not item_type:
             return None
         return self._registry.get(item_type)
+
+    def get_config_registry(self) -> WithConfigRegistry:
+        return self
