@@ -1,9 +1,11 @@
 from __future__ import annotations
 
-from pathlib import Path
+from typing import TYPE_CHECKING
 
 import yaml
-from wexample_pseudocode.generator.pseudocode_generator import PseudocodeGenerator
+
+if TYPE_CHECKING:
+    from pathlib import Path
 
 
 def load_file(path: Path) -> str:
@@ -11,6 +13,10 @@ def load_file(path: Path) -> str:
 
 
 def test_constant_using_const(resources_dir) -> None:
+    from pathlib import Path
+
+    from wexample_pseudocode.generator.pseudocode_generator import PseudocodeGenerator
+
     source_path = resources_dir / "constant_using_const.py"
     expected_yaml_path = resources_dir / "constant_using_const.yml"
 
